@@ -4,13 +4,28 @@ use TestML::Runtime -base;
 
 use Test::Builder;
 
+if ($TestML::Test::Differences) {
+    no warnings 'redefine';
+    require Test::Differences;
+    *Test::Builder::is_eq = sub {
+        my $self = shift;
+        \&Test::Differences::eq_or_diff(@_);
+    };
+}
+
 has 'test_builder' => -init => 'Test::Builder->new';
 
 sub title {
     my $self = shift;
     if (my $title = $self->function->getvar('Title')) {
         $title = $title->value;
-        $self->test_builder->note("=== $title ===\n");
+        $title = "=== $title ===\n";
+        if ($self->test_builder->can('note')) {
+            $self->test_builder->note($title);
+        }
+        else {
+            $self->test_builder->diag($title);
+        }
     }
 }
 
